@@ -25,3 +25,7 @@ INSERT INTO diogenes_logactions VALUES (9, 'barrel_create', 'a new barrel was cr
 INSERT INTO diogenes_logactions VALUES (10, 'barrel_delete', 'a complete barrel was deleted');
 INSERT INTO diogenes_logactions VALUES (11, 'file_upload', 'a file was uploaded');
 INSERT INTO diogenes_logactions VALUES (12, 'file_delete', 'a file was deleted');
+INSERT INTO diogenes_logactions VALUES (13, 'barrel_options', 'the barrel options were updated');
+INSERT INTO diogenes_logactions VALUES (14, 'barrel_plugins', 'the barrel plugins were modified');
+INSERT INTO diogenes_logactions VALUES (15, 'page_props', 'the page properties were updated');
+INSERT INTO diogenes_logactions VALUES (16, 'page_plugins', 'the page plugins were modified');
