@@ -1,11 +1,11 @@
 -- phpMyAdmin SQL Dump
--- version 2.6.1
+-- version 2.6.1-pl3
 -- http://www.phpmyadmin.net
 -- 
 -- Host: localhost
--- Generation Time: Mar 13, 2005 at 11:08 PM
--- Server version: 4.0.23
--- PHP Version: 4.3.10-7
+-- Generation Time: Apr 09, 2005 at 01:25 AM
+-- Server version: 4.0.24
+-- PHP Version: 4.3.10-10
 -- 
 -- Database: `diogenes`
 -- 
@@ -62,7 +62,7 @@ CREATE TABLE `diogenes_logevents` (
 -- 
 
 CREATE TABLE `diogenes_logsessions` (
-  `id` int(6) NOT NULL auto_increment,
+  `id` int(10) unsigned NOT NULL auto_increment,
   `auth` enum('native','external') NOT NULL default 'native',
   `uid` int(10) unsigned NOT NULL default '0',
   `start` timestamp(14) NOT NULL,
@@ -83,9 +83,10 @@ CREATE TABLE `diogenes_logsessions` (
 -- 
 
 CREATE TABLE `diogenes_option` (
+  `barrel` VARCHAR( 16 ) NOT NULL default '',
   `name` varchar(32) NOT NULL default '',
   `value` text NOT NULL,
-  PRIMARY KEY  (`name`)
+  PRIMARY KEY  (`barrel`, `name`)
 ) TYPE=MyISAM;
 
 -- --------------------------------------------------------
@@ -104,6 +105,22 @@ CREATE TABLE `diogenes_perm` (
 
 -- --------------------------------------------------------
 
+-- 
+-- Table structure for table `diogenes_plugin`
+-- 
+
+CREATE TABLE `diogenes_plugin` (
+  `plugin` varchar(32) NOT NULL default '',
+  `barrel` varchar(16) NOT NULL default '',
+  `page` int(10) unsigned NOT NULL default '0',
+  `pos` int(10) unsigned NOT NULL default '0',
+  `params` text NOT NULL,
+  PRIMARY KEY  (`plugin`,`barrel`,`page`),
+  KEY `pos` (`pos`)
+) TYPE=MyISAM;
+
+-- --------------------------------------------------------
+
 -- 
 -- Table structure for table `diogenes_site`
 -- 
@@ -121,4 +138,4 @@ CREATE TABLE `diogenes_site` (
 -- Set the database format version
 --
 
-INSERT INTO `diogenes_option` SET name='dbversion', value='0.9.15';
+INSERT INTO `diogenes_option` SET name='dbversion', value='0.9.16+0.9.17pre21';
