@@ -15,7 +15,8 @@ if (preg_match("/^\/([^\/]+)\/webdav(\/.*)?$/",$_SERVER['PATH_INFO'],$tmp)) {
     readfile($afile);
   } else {
     // include the requested admin page
-    require("admin/". ($afile ? "$afile.php" : "index.php"));
+    if (!$afile) $afile = "index";    
+    require("admin/$afile.php");
   }
 
 } else {
