@@ -77,9 +77,9 @@ class DiogenesAdmin extends DiogenesBarrel
     array_push($this->menu, array( 1, __("Users"), "users") );
     array_push($this->menu, array( 1, __("WebDAV"), "webdav") );
     array_push($this->menu, array( 0, __("Content"), "", 1 ) );
-    array_push($this->menu, array( 1, __("Pages catalog"), "pages") );
+    array_push($this->menu, array( 1, __("Pages catalog"), "files?dir={$homepage}&amp;file={$globals->cssfile}") );
     array_push($this->menu, array( 1, __("Edit style sheet"), "edit?dir={$homepage}&amp;file={$globals->cssfile}") );
-    array_push($this->menu, array( 1, __("Edit menus"), "menus") );
+    array_push($this->menu, array( 1, __("Edit menu"), "menus") );
   }
 
 }
