@@ -23,6 +23,7 @@
   require_once 'diogenes/diogenes.database.inc.php';
   require_once 'diogenes.session.inc.php';
   require_once 'diogenes.cvs.inc.php';
+  require_once 'Plugins.php';
 
   // get custom definitions
   $globals = new DiogenesGlobals();
@@ -38,6 +39,12 @@
   // read extra options from database
   $globals->readOptions();
 
+  // set up the plugin holder
+  $globals->plugins = new Diogenes_Plugins($globals->db, $globals->root . "/plugins", $globals->spoolroot . "/diogenes_c");
+
+  // set up the icons
+  $globals->icons = new DiogenesIcons();
+
   // do we want to debug database calls ?
   if ($globals->debugdatabase)
     $globals->db->trace_on();
