@@ -33,7 +33,7 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
   /** The Diogenes root URL */
   var $rooturl;
   /** The Diogenes version */
-  var $version = "0.9.19";
+  var $version = "0.9.20";
 
   /** A barrel's stylesheet */
   var $cssfile = "style.css";
@@ -116,6 +116,16 @@ class DiogenesGlobals extends DiogenesCoreGlobals {
                            'lush' => 'lush',
                            'mozilla' => 'mozilla'
                           );
+
+   /** Available style sheets */
+   var $style_sheets = array(
+                           'default_blue' => 'Default Blue',
+                           'fresh_blue' => 'Fresh Blue',
+                           'funky_doc' => 'Funky Doc',
+                          );
+  
+  /** Default stylesheet for new barrels */
+  var $barrel_style_sheet = 'default_blue';
   
   /** The HTML editor to use (ekit, kafenio) */
   var $html_editor = "kafenio";
