@@ -53,6 +53,11 @@ class DiogenesTableEditor extends DiogenesDatabaseTable {
   /** Maximum number of results per page, 0 for unlimited */
   var $maxrows = 0;
 
+  /** CSS class of the table that contains the editor */
+  var $table_class = "light";
+  /** Extra CSS style info for the table that contains the editor */
+  var $table_style = "";
+  
   /** The constructor.
    *
    * @param $table   the MySQL table we are operating on
@@ -479,7 +484,6 @@ class DiogenesTableEditor extends DiogenesDatabaseTable {
       $sql = $this->make_select(true,$ncols);
       $res = $this->dbh->query($sql);
       $page->assign('ncols',$ncols);
-      $odd = true;
 
       // determine start and stop of displayed results
       $p_total = mysql_num_rows($res);
@@ -497,9 +501,8 @@ class DiogenesTableEditor extends DiogenesDatabaseTable {
 
             array_push($actions, array($myaction['text'],$url));
           }
-          $page->append('rows', array( $odd ? "odd" : "even", $myarr[$this->idfield], $myarr, $actions) );
+          $page->append('rows', array($myarr[$this->idfield], $myarr, $actions) );
         }
-        $odd = !$odd;
 	$counter++;
       }
       mysql_free_result($res);
@@ -518,7 +521,9 @@ class DiogenesTableEditor extends DiogenesDatabaseTable {
     $page->assign('readonly',$this->readonly);
     if ($this->readonly && ($this->actions == array()))
       $page->assign('hideactions', 1);
-
+    $page->assign('table_class', $this->table_class);
+    $page->assign('table_style', $this->table_style);
+      
     // translations
     $page->assign('msg_previous_page', __("previous page"));
     $page->assign('msg_next_page', __("next page"));
